Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2326)

Unified Diff: chrome/browser/ui/cocoa/bookmarks/bookmark_bar_controller.mm

Issue 1948963002: [Mac][Material Design] Fix toolbar height on Retina. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Fix comment. Created 4 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | chrome/browser/ui/cocoa/location_bar/autocomplete_text_field.mm » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/ui/cocoa/bookmarks/bookmark_bar_controller.mm
diff --git a/chrome/browser/ui/cocoa/bookmarks/bookmark_bar_controller.mm b/chrome/browser/ui/cocoa/bookmarks/bookmark_bar_controller.mm
index 0b7f2aa3064225b9d7d285f20af5f54590e44202..21e09b7dc9be76f0a51ff751b8cad5201e8d54df 100644
--- a/chrome/browser/ui/cocoa/bookmarks/bookmark_bar_controller.mm
+++ b/chrome/browser/ui/cocoa/bookmarks/bookmark_bar_controller.mm
@@ -67,6 +67,7 @@
#import "ui/base/cocoa/cocoa_base_utils.h"
#import "ui/base/cocoa/nsview_additions.h"
#include "ui/base/l10n/l10n_util_mac.h"
+#include "ui/base/material_design/material_design_controller.h"
#include "ui/base/resource/resource_bundle.h"
#include "ui/gfx/image/image.h"
#include "ui/resources/grit/ui_resources.h"
@@ -1029,14 +1030,27 @@ void RecordAppLaunch(Profile* profile, GURL url) {
if (!barIsEnabled_)
return 0;
+ CGFloat lineWidth = 0;
+ BOOL isRetina = NO;
+ BOOL reduceHeight = YES;
+
switch (currentState_) {
case BookmarkBar::SHOW:
- // When on a Retina display, -[ToolbarContrller baseToolbarHeight] reduces
- // the height of the toolbar by 1pt. In this case the bookmark bar needs
- // to be 1pt taller to maintain the proper spacing between bookmark icons
- // and toolbar items. See https://crbug.com/326245 .
- return [[self view] cr_lineWidth] == 0.5 ? chrome::kBookmarkBarHeight + 1
- : chrome::kBookmarkBarHeight;
+ // When on a Retina display and not using Material Design,
+ // -[ToolbarController baseToolbarHeight] reduces the height of the
+ // toolbar by 1pt. In this case the bookmark bar needs to add 1pt of space
+ // above the bookmark icons in order to maintain the proper distance from
+ // toolbar items. See https://crbug.com/326245 .
+ lineWidth = [[self view] cr_lineWidth];
+ isRetina = (lineWidth < 1);
+
+ // If Material Design and Retina, no height adjustment is needed.
+ if (ui::MaterialDesignController::IsModeMaterial() && isRetina) {
+ reduceHeight = NO;
+ }
+
+ return reduceHeight ? chrome::kBookmarkBarHeight + 1
+ : chrome::kBookmarkBarHeight;
case BookmarkBar::DETACHED:
return chrome::kNTPBookmarkBarHeight;
case BookmarkBar::HIDDEN:
« no previous file with comments | « no previous file | chrome/browser/ui/cocoa/location_bar/autocomplete_text_field.mm » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698